<?php
/**
 * Review Meta Box
 */
function rswpbs_book_review_meta_box() {
	 add_meta_box(
	    'rswpbs_book_review_meta_box',       // ID of the meta box
	    'Book Review Details',        // Title of the meta box
	    'rswpbs_book_review_meta_box_cb',    // Callback function
	    'book_reviews',                // Post type
	    'advanced',                       // Context
	    'default'                     // Priority
	);
}
add_action('add_meta_boxes', 'rswpbs_book_review_meta_box');

function rswpbs_book_review_meta_box_cb($post) {
	wp_nonce_field('rswpbs_save_book_review_meta_box', 'rswpbs_book_review_meta_nonce_field');

	// get the current values of the custom fields
	$reviewer_name = get_post_meta($post->ID, '_rswpbs_reviewer_name', true);
	$reviewer_email = get_post_meta($post->ID, '_rswpbs_reviewer_email', true);
	$rating = get_post_meta($post->ID, '_rswpbs_rating', true);
	$reviewed_book = get_post_meta($post->ID, '_rswpbs_reviewed_book', true);

	// output the form fields
	?>
	<div class="row">
		<div class="col-lg-3">
			<div class="rswpbs-review-cmb-field">
				<label for="reviewed_book"><?php esc_html_e( 'This Review Was Submited in: ', RSWPBS_TEXT_DOMAIN );?></label><br>
				<input type="hidden" name="reviewed_book" id="reviewed_book" value="<?php echo esc_attr( $reviewed_book ); ?>">
				<?php
				if (!empty($reviewed_book)) :
				?>
					<h4><a href="<?php echo get_the_permalink($reviewed_book);?>"><?php echo get_the_title( $reviewed_book );?></a></h4>
				<?php endif; ?>
			</div>
		</div>
		<div class="col-lg-3">
			<div class="rswpbs-review-cmb-field">
				<label for="name"><?php esc_html_e( 'Full Name:', RSWPBS_TEXT_DOMAIN );?></label><br>
				<input type="text" name="name" id="name" value="<?php echo esc_attr($reviewer_name); ?>">
			</div>
		</div>
		<div class="col-lg-3">
			<div class="rswpbs-review-cmb-field">
				<label for="email"><?php esc_html_e( 'Email Address:', RSWPBS_TEXT_DOMAIN );?></label><br>
				<input type="email" name="reviewer_email" id="email" value="<?php echo esc_attr($reviewer_email); ?>">
			</div>
		</div>
		<div class="col-lg-3">
			<div class="rswpbs-review-cmb-field">
				<label for="rating"><?php esc_html_e( 'Rating:', RSWPBS_TEXT_DOMAIN );?></label><br>
				<select name="rating" id="rating">
					<option value="1" <?php selected($rating, 1); ?>>1</option>
					<option value="2" <?php selected($rating, 2); ?>>2</option>
					<option value="3" <?php selected($rating, 3); ?>>3</option>
					<option value="4" <?php selected($rating, 4); ?>>4</option>
					<option value="5" <?php selected($rating, 5); ?>>5</option>
				</select>
			</div>
		</div>
	</div>

  <?php
}


function rswpbs_save_book_review_meta_box($post_id) {
	// check for nonce
	if (!isset($_POST['book_review_meta_box_nonce']) || !wp_verify_nonce($_POST['book_review_meta_box_nonce'], 'rswpbs_save_book_review_meta_box')) {
		return;
	}
	// check for permissions
	if (!current_user_can('edit_post', $post_id)) {
		return;
	}
	// save the custom fields
	if (isset($_POST['reviewed_book'])) {
		update_post_meta($post_id, '_rswpbs_reviewed_book', intval($_POST['reviewed_book']));
	}
	if (isset($_POST['reviewer_name'])) {
		update_post_meta($post_id, '_rswpbs_reviewer_name', sanitize_text_field($_POST['reviewer_name']));
	}
	if (isset($_POST['reviewer_email'])) {
		update_post_meta($post_id, '_rswpbs_reviewer_email', sanitize_email($_POST['reviewer_email']));
	}
	if (isset($_POST['rating'])) {
		update_post_meta($post_id, '_rswpbs_rating', intval($_POST['rating']));
	}
}
add_action('save_post', 'rswpbs_save_book_review_meta_box');
